// Homeland Security
// Copyright 2003 Macromedia

#include "shared/debugging.as"
#include "shared/interfaces.as"

var gAppName:String = "Homeland";

var gShell:mx.central.Shell;		// reference to the Central Shell API
var gAppID:String;		// unique id of this application instance
var gCom;		// local connection to communicate with agent
var gOnline:Boolean = true;	// assume we're online unless we hear otherwise
var gThreat:String = null;

// associate threat levels with messages
var gLevels:Array = new Array();
gLevels["SEVERE"] = {color: 0xFF0000, message: "Severe Risk of\rTerrorist Attacks"};
gLevels["HIGH"] = {color: 0xFF6600, message: "High Risk of\rTerrorist Attacks"};
gLevels["ELEVATED"] = {color: 0xFFCC00, message: "Significant Risk of\rTerrorist Attacks"};
gLevels["GUARDED"] = {color: 0x0099FF, message: "General Risk of\rTerrorist Attacks"};
gLevels["LOW"] = {color: 0x66CC66, message: "Low Risk of\rTerrorist Attacks"};
gLevels["UNKNOWN"] = {color: 0xFFFFFF, message: "Can't access Department of\rHomeland Security"};


//-------------------------------------------------------------------
// Central Event Handling
//

// onActivate is called by the Shell when this application is first loaded
function onActivate(shell, appID, shellID, baseTabIndex, initialData)
{
	gShell = shell;
	gAppID = appID;
	gAppName += shellID;
	
	// establish local connection to agent for data
	gCom = Central.LCService.createClient( HomelandService, gAppName, this, false );
	gCom.getThreat();
	gCom.getNotify();

	onNetworkChange(gShell.isConnected());

    // make sure we're aware of changes to the combo box
    fNotify.addEventListener("change",  changeListener);
	
	// now we check back in a second to see if we have our data yet
	// this is only an issue on initial loading since we might be loaded before our agent
	gDataCheck = setInterval(checkForData, 1000);
}

function checkForData()
{
	if (gThreat == null)
	{
		// we don't have it yet, so ask agent for current data again
		gCom.getThreat();
		gCom.getNotify();
	}
	else
	{
		// we have it, so stop checking
		clearInterval(gDataCheck);
		gDataCheck = null;
	}
}

// onDeactivate is called when this application is being closed
function onDeactivate()
{
	mytrace("onDeactivate");
	gCom.close();
	
	// if we were still waiting for data, clear that now
	if (gDataCheck != null)
	{
		clearInterval(gDataCheck);
	}
}

function onNetworkChange(online:Boolean)
{
	mytrace("onNetworkChange: "+(online ? "online" : "offline"));
	gOnline = online;
}

//-------------------------------------------------------------------
// Button Events
//

// clicking on the level text or background takes you to the DHS web site
fLevel.onRelease = function()
{
	getURL("http://www.dhs.gov/dhspublic/display?theme=29");
}
fBackground.onRelease = fLevel.onRelease;

// rolling over the little color boxes shows the various states
fGreen.onRollOver = function() { setDisplay("LOW"); }
fGreen.onRollOut = refreshDisplay;
fBlue.onRollOver = function() { setDisplay("GUARDED"); }
fBlue.onRollOut = refreshDisplay;
fYellow.onRollOver = function() { setDisplay("ELEVATED"); }
fYellow.onRollOut = refreshDisplay;
fOrange.onRollOver = function() { setDisplay("HIGH"); }
fOrange.onRollOut = refreshDisplay;
fRed.onRollOver = function() { setDisplay("SEVERE"); }
fRed.onRollOut = refreshDisplay;

fShowPod.onRelease = function()
{
	// display a pod if there's not already one shown
	var shownPods:Array = gShell.getViewedPods();	
	if (shownPods.length == 0)
	{
		var pods:Array = gShell.getPods();
		gShell.viewPod(pods[0].id);
	}
}

fHeader.onRelease = function()
{
	// click on header to go to the DHS site
	getURL("http://www.dhs.gov/");
}

fPhoto.onRelease = function()
{
	// click on photo to read about this stuff
	getURL("http://www.dhs.gov/dhspublic/theme_home6.jsp");
}

var changeListener:Object = new Object;
changeListener.change = function(event)
{
	// when the user chooses a new notification level, tell agent to
	// store the preference
    var component = event.target;
	gCom.setNotify(component.selectedItem.data);
}

//-------------------------------------------------------------------
// View Updating
//

function setDisplay(threat:String)
{
	fLevel.fDisplay.text = threat;
	fDescription.text = gLevels[threat].message;
	
	// set color of background to match threat level
	var bColor = new Color(fBackground);
	bColor.setRGB(gLevels[threat].color);
	delete bColor;
}

function refreshDisplay()
{
	//mytrace("refreshDisplay "+gThreat);
	setDisplay(gThreat);
}

//-------------------------------------------------------------------
// Agent Communication
//

// Handle result from calling getThreat API on our agent
function getThreat_Result(result)
{
	setThreat(result);
}

// Handle result from calling getNotify API on our agent
function getNotify_Result(result)
{
	setNotify(result);
}

// Handle calls from our agent to set threat level
function setThreat(level)
{
	//mytrace("setThreat "+level);
	gThreat = level;
	refreshDisplay();
}

// Handle calls from our agent to set notice preference
function setNotify(notify)
{
	//mytrace("setNotify "+notify);
	fNotify.setSelectedIndex(notify);
}


//-------------------------------------------------------------------
// Initialization
//

// let Central know our application is loaded
Central.initApplication(this, this);

