// Generic Installer
//
// This contains just a button to download and install any product in Central
// if the product.xml is in the same directory as this swf (and is named 'product.xml')
// this movie will start the download of that product.
// You should not have to rebuild this movie.
//
// Copyright 2003 Macromedia

#include "CentralInstall.as"

// -------------------------------------------------
// this points to your product descriptor XML file,
// assuming it is named 'product.xml' and in the same folder as this installer.swf

baseUrl = _url.slice(0, _url.lastIndexOf('/'));
gProductUrl = baseUrl + "/product.xml";
gInstallUrl = "";
gProductInfo = new Object();
gCanInstall = false;		// whether this Flash Player can install Central apps
gCentralProduct = new System.Product("Central");

// if this is set to true, the words "Public Beta" are placed in the installer header frame
kPublicBeta = false;

// -------------------------------------------------
// This information is used to describe Central when it will be installed by itself
// rather than along with a product

kBullet = String.fromCharCode(0x2022);
kCentralName = "Macromedia Central";
kCentralSize = "1.8MB";
kCentralDescription = "A new way to interact with distributed information.\r\r"+
					  kBullet+" Free, simple installation\r"+
					  kBullet+" Manage info outside the browser\r"+
					  kBullet+" Share data across applications";

kCentralAlreadyInstalled = "Macromedia Central is already installed.\r\rIf you'd like to install Central again, please uninstall your current copy of Central first.";

kOldPlayerMessage = "<FONT COLOR=\"#FF0000\"><FONT FACE=\"Verdana\" SIZE=\"12\">Installing this product with Macromedia Central requires the current <a href=\042http://macromedia.com/go/getflashplayer\042><u>Macromedia Flash Player</u></a>.";

// checkPlayer result codes
kInstallOK = 0;
kOldPlayer = 1;

// -------------------------------------------------
// This portion tests to see if the user's version of the Flash Plugin is new enough

function checkPlayer()
{
	// get user's player version, such as: WIN 7,0,0,264
	var version = System.capabilities.version;
	var playerRev = version.split(",")[2];
	var playerVersion = version.split(",")[0];
	var platform = playerVersion.substring(0,playerVersion.indexOf(" "));
	var result = 0;

	// strip off the platform text to get just player version number
	playerVersion = playerVersion.substr(playerVersion.indexOf(" ")+1);

	// minimum player version required to install Central is 6.0r65
	var kMinPlayerVersion = 6;
	var kMinPlayerRev = 65;

	// check to make sure this Flash Player is new enough to install Central and we can run on platform
	myTrace("platform="+platform+" version="+playerVersion+" rev="+playerRev+" ("+version+")");
	if ((playerRev < kMinPlayerRev) && (playerVersion <= kMinPlayerVersion))
	{
		// this player version can't install Central
		result = kOldPlayer;
	}
	return result;
}

//---------------------------------------------------
// Product.xml reader

function loadProductXML(success)
{
	myTrace("productXML load "+(success ? "succeeded" : "failed **"))
	var p = gXML.firstChild;
	if (p.nodeName == "product")
	{
		gInstallUrl = gProductUrl;
		gProductInfo.name = p.attributes.name;
		gProductInfo.description = null;
		gProductInfo.downloadSize = null;
		gProductInfo.iconSrc = null;
		gProductInfo.iconSize = null;

		var len = p.childNodes.length;
		for (var i=0; i<len; i++)
		{
			var node = p.childNodes[i];
			switch (node.nodeName)
			{
				case "description":
					// if we didn't already get a description, use the generic one
					if (gProductInfo.description == null)
					{
						gProductInfo.description = node.firstChild.nodeValue;
					}
					break;

				case "installerDescription":
					// always override with the description for the installer if available
					gProductInfo.description = node.firstChild.nodeValue;
					break;

				case "downloadSize":
					gProductInfo.downloadSize = node.firstChild.nodeValue;
					break;

				case "icon":
					// remember the largest icon defined
					if ((gProductInfo.iconSrc == null) || (Number(node.attributes.size) > Number(gProductInfo.iconSize)))
					{
						gProductInfo.iconSrc = node.attributes.src;
						gProductInfo.iconSize = node.attributes.size;
					}
					break;

				case "application":
					// if we don't have an icon yet, look for one in the apps
					var appLen = node.childNodes.length;
					for (var j=0; (j<appLen) && (gProductInfo.iconSrc == null); j++)
					{
						var appNode = node.childNodes[j];
						if ((appNode.nodeName == "icon") && (gProductInfo.iconSrc == null) || (Number(appNode.attributes.size) > Number(gProductInfo.iconSize)))
						{
							gProductInfo.iconSrc = appNode.attributes.src;
							gProductInfo.iconSize = appNode.attributes.size;
						}
					}
					break;
			}
		}

		// show correct Install button depending on whether we're installing with Central or not
		fInstallButton.fAlreadyInstalled._visible = false;
		if (!gCentralProduct.isInstalled())
		{
			fInstallButton.fInstallNow._visible = false;
			fInstallButton.fInstallWithCentral._visible = true;
		}
		else
		{
			fInstallButton.fInstallNow._visible = true;
			fInstallButton.fInstallWithCentral._visible = false;
		}
	}

	displayInfo();
}

function displayInfo()
{
	// display name, size
	fInstallButton.fName.text = gProductInfo.name;
	fPod.fTitle.text = (kPublicBeta ? "Public Beta" : "Macromedia Central");
	if (gProductInfo.downloadSize != null)
	{
		fInstallButton.fSize.text = gProductInfo.downloadSize+" download";
	}
	else
	{
		fInstallButton.fSize.text = "";
	}

	// if we're not showing the old player warning, show product description
	if (gCanInstall)
	{
		fMessage.htmlText = gProductInfo.description;
	}

	// display icon, scale to 40x40 size
	if (gProductInfo.iconSrc == "")
	{
		fInstallButton.fIcon.attachMovie("CentralLogo", "centralicon", 1);
	}
	else
	{
		// add complete path if this is a relative reference
		if (gProductInfo.iconSrc.subStr(0,5).toLowerCase() != "http:")
		{
			gProductInfo.iconSrc = baseUrl + "/" + gProductInfo.iconSrc;
		}
		fInstallButton.fIcon.loadMovie(gProductInfo.iconSrc);
	}
	var scale = Math.round((40/gProductInfo.iconSize)*100);
	fInstallButton.fIcon.xscale = scale;
	fInstallButton.fIcon.yscale = scale;
}

// -------------------------------------------------
// Click handler for the Install button

// The document containing this button must be at least 220x150 pixels in size
// so the Flash Player can show the Flash Central installation dialog if necessary.

fInstallButton.onRelease = function()
{
	switch (checkPlayer())
	{
		case kInstallOK:
		     if (gCanInstall)
		     {
				 myTrace("installing "+ gInstallUrl);

				 // create an InstallService for this product
				 installService = new fcInstallService( responseHandler, gInstallUrl, 30 );

				 // start the install process
				 installService.start();
			 }
		     break;

		case kOldPlayer:
		     getURL("http://macromedia.com/go/getflashplayer");
		     break;
	}
}

// handle lighting up the install button when mouse is over it
fInstallButton.onRollOver = function()
{
	if (gCanInstall)
	{
		fInstallButton.fLight._visible = true;
		fInstallButton.fInstallNow.textColor = 0x0094D5;
		fInstallButton.fInstallWithCentral.textColor = 0x0094D5;
	}
}

fInstallButton.onRollOut = function()
{
	if (gCanInstall)
	{
		fInstallButton.fLight._visible = false;
		fInstallButton.fInstallNow.textColor = 0x71828A;
		fInstallButton.fInstallWithCentral.textColor = 0x71828A;
	}
}

// create a response handler to receive information on installation progess
var responseHandler = new Object();
responseHandler.onStatus = function(status)
{
	// install finishes with status.code of "InstallService.Success" or "InstallService.Failed"
	myTrace("installer: "+status.level+" "+status.code);
}

// -------------------------------------------------
// Initialization

fInstallButton.fLight._visible = false;
fInstallButton.fInstallNow._visible = false;
fInstallButton.fInstallWithCentral._visible = false;
fInstallButton.fAlreadyInstalled._visible = false;

// default to Central info
gProductInfo.name = kCentralName;
gProductInfo.description = "";
gProductInfo.downloadSize = null;
gProductInfo.iconSrc = "";
gProductInfo.iconSize = 40;

// check if the current player is too old to work with Central
switch (checkPlayer())
{
	case kInstallOK:
		gCanInstall = true;

		// installer is not next to a valid product.xml file, so just install Central
		if (gCentralProduct.isInstalled())
		{
			// Central is already installed, so show message
			gProductInfo.description = kCentralAlreadyInstalled;
			fInstallButton.fAlreadyInstalled._visible = true;
		}
		else
		{
			// show Central description
			gProductInfo.description = kCentralDescription;
			gProductInfo.downloadSize = kCentralSize;
			fInstallButton.fInstallNow._visible = true;
		}

		break;

	case kOldPlayer:
		// tell user they need to get a more recent player
		fMessage.htmlText = kOldPlayerMessage;
		break;
}


// display information about the product to be installed
gXML = new XML();
gXML.ignoreWhite = true;
gXML.onLoad = loadProductXML;
myTrace("reading productXML: "+gProductUrl);
gXML.load(gProductUrl);


// -------------------------------------------------
// debugging

function myTrace(message)
{
	trace(message);
	var debuglc = new LocalConnection();
	debuglc.send("_tracer", "onMessage", message);
	delete debuglc;
}

// prevent scaling
Stage.scaleMode = "noScale";
Stage.align = "TL";

